#!/bin/bash

#############################################################
# 1. Setup
#############################################################

# standards : 96x95x39, 144x142x79

grid_resolution=32x32x39
an=clim
veget=0
parallel=0
mpi=4
omp=2
machine=local



hostname=`hostname`
if [ ${hostname:0:5} = ada33 ] ; then
   machine=X64_ADA
fi



#------------------------------------------------------------
# 1.1 Mode parallele / sequentiel
#------------------------------------------------------------
modipsl=`pwd | sed -n -e 's/modipsl.*.$/modipsl/p'`

if [ $parallel = 1 ] ; then
   opt_compile="-mem -parallel mpi_omp -arch $machine"
   rungcm="./run_$machine.sh $mpi $omp gcm.e"
   runini="./run_$machine.sh 1 1 ce0l.e"
else
   opt_compile=""
   rungcm="./gcm.e"
   runini="./ce0l.e"
fi

################################################################################
# Default path for the input files
# Will be overpassed using wget if not available
get="wget http://www.lmd.jussieu.fr/~lmdz/LMDZ_Init/"
for dirinit in /u/lmdz/WWW/LMDZ_Init /u/lmdz/WWW/LMDZ_Init ~/LMDZ/LMDZ_Init ; do
   if [ -d $dirinit ] ; then
       get="ln -s $dirinit/"
   fi
done

\rm -f tmp.*
if [ $veget = 0 ] ; then
   optveget=""
   VEGET=n
else
   optveget="-v orchidee2.0"
   VEGET=y
fi


#########################################################################
# Model location
#########################################################################
if [ `pwd | grep modipsl` ] ; then
   MODEL=`pwd | sed -e 's/.modipsl/ /' | awk ' { print $1 } '`
   LMDZ=$MODEL/modipsl/modeles/LMDZ5
else
   echo Mettre emplacement du modele a la main
fi
SIMU=`pwd`
if [ ! -f DEF/run.def -o ! -f DEF/physiq.def -o ! -f DEF/gcm.def ] ; then
    echo Il n y a pas de fichier run.def ou physiq.def ou gcm.def dans le
    echo repertoire $SIMU. Vous pouvez en recuperer sur
    echo $LMDZ/DefLists
    exit
fi

echo
echo '#############################################################'
echo '  0. Model Compilation                                       '
echo '#############################################################'

echo 'Checking the consistency of the compilation and installation'
compilo=`grep COMPIL $LMDZ/arch/arch-local.fcm | awk ' { print $2 } '`
if [ "$machine" = "local" -a "$compilo" = "mpif90" -a $parallel = 0 ] ; then
    echo You try to work in serial mode while the model was install in parallel
    exit # if you are an expert, you can modify this
fi
if [ "$machine" = "local" -a "$compilo" = "gfortran" -a $parallel = 1 ] ; then
    echo You try to work in parallel mode while the model was install in serial
    exit # if you are an expert, you can modify this
fi

cd $LMDZ
for mod in gcm ce0l ; do
   echo compiling $mod
   echo ./makelmdz -d $grid_resolution $optveget $opt_compile $mod
   ./makelmdz -d $grid_resolution $optveget $opt_compile $mod
   if [ -f $mod.e ] ; then
      mv $mod.e $SIMU/
   else
      echo Echec pour la compilation de lmdz ; exit
   fi
done


echo
echo '###############################################################'
echo '  2. Creating initial state and boundary conditions'
echo '###############################################################'
echo '  in files start.nc, startphy.nc, limit.nc             '
echo 
echo '...............................................................'
echo '  2.1  Geting input files from the web                         '
echo '...............................................................'
mkdir -p $SIMU/INITIAL
cd $SIMU/INITIAL
ln -s ../*.e ../*.sh .
cp ../DEF/*def .

if [ "$an" = "clim" ] ; then
   suf=1x1_clim
else
   suf=360x180_$an
fi

echo Input files downloaded from : $get
for file in Albedo.nc ECDYN.nc Relief.nc Rugos.nc landiceref.nc \
            amipbc_sic_$suf.nc amipbc_sst_$suf.nc ; do
   if [ -f $file ] ; then
# If input files are already there, do not download
      echo File $file is there already
   else
      ${get}$file
   fi
done

if [ -f amipbc_sst_$suf.nc ] ;  then
    ln -sf ECDYN.nc ECPHY.nc
    ln -sf amipbc_sic_$suf.nc amipbc_sic_1x1.nc
    ln -sf amipbc_sst_$suf.nc amipbc_sst_1x1.nc
else
    echo Les fichiers n ont pas ete telecharges correctement ; exit
fi

echo
echo '...............................................................'
echo ' 2.2 Running ce0l.e  (output listing in ce0l.out)              '
echo '...............................................................'
$runini > ce0l.out 2>&1

echo
echo '.....................................................'
echo ' 2.1 Creating a figure for the grid named grid.pdf'
echo '.....................................................'
cat <<eod>| tmp.jnl
use grilles_gcm.nc
let rel=if (abs(grille_s-1) gt 0.5) then phis
shade/pal=land_sea_values rel ; go land
let deep=if (rel lt 0.1) then rel
shade/pal=blue/o deep
quit
eod
ferret -batch tmp.ps -nojnl -script  tmp.jnl > out.ferret 2>&1
ps2epsi tmp.ps ; epstopdf tmp.ps ; \mv tmp.pdf grille.pdf >>  out.ferret 2>&1

cd ../
mkdir SIMU1


if [ $veget != 0 ] ; then

   echo
   echo '...............................................................'
   echo ' 2.3 : preparting simulations with Orchidee'
   echo '...............................................................'
   echo '   Geting input files from the web for Orchidee                '


   mkdir SIMU0 ; cd SIMU0
   for file in PFTmap_IPCC_2000.nc cartepente2d_15min.nc \
                     routing.nc lai2D.nc soils_param.nc ; do
      ${get}$file
   done
   ln -sf PFTmap_IPCC_2000.nc PFTmap.nc

   # Modifying .def files for a first 1-day simulation
   cp -f ../DEF/*def .
   sed -e 's/VEGET=.*.$/VEGET='$VEGET'/' ../DEF/config.def >| config.def
   sed -e 's/nday=.*.$/nday=1/' ../DEF/run.def >| run.def
   sed -e 's/^SECHIBA_restart_in=.*./SECHIBA_restart_in=NONE/' \
                               ../DEF/orchidee.def >| orchidee.def
   ln -s ../INITIAL/start.nc ../INITIAL/startphy.nc ../INITIAL/limit.nc .
   ln -s ../gcm.e ../*sh .

   echo ' NOTICE : To run the model with orchidee, you need to run a first'
   echo ' simulation to create the orchidee initial file'
   echo ' cd SIMU0'
   echo   $rungcm' > listing0                           '
   echo 'Then,'

   cd ../SIMU1
   ln -s ../SIMU0/restart.nc start.nc
   ln -s ../SIMU0/restartphy.nc startphy.nc
   ln -s ../SIMU0/sechiba_rest_out.nc sechiba_rest_in.nc

else

   cd SIMU1
   ln -s ../INITIAL/start.nc ../INITIAL/startphy.nc .

fi


####################################################################
# Preparing a Directory for a first simulation :
####################################################################

ln -s ../gcm.e ../*.sh .
cp ../DEF/*def .
sed -e 's/VEGET=.*.$/VEGET='$VEGET'/' ../DEF/config.def >| config.def
ln -s ../INITIAL/limit.nc .


echo "to run a simulation :"
echo "cd SIMU1"
echo   $rungcm' > listing0'
echo 'enjoy it'
